@@ -40,4 +40,4 @@ class FlashSpeed(enum.IntEnum):
 
 
 class MusicSelections(enum.Enum):
-    RINGING = 1
+    pass
